@@ -5,19 +5,21 @@
 #' companion header file.
 #'
 #' @param x Character. Vector of local filepaths.
-#' @param header Character. Companion header files corresponding to the binary data
+#' @param flag Logical. If \code{TRUE}, returns flag values instead of NDVI. See
+#' 'References' for further reading. Note that this will be ignored if
+#' \code{scaling = FALSE}.
+#' @param header Character. Header file(s) corresponding to the binary data
 #' in 'x'. If missing, the standard header file for GIMMS NDVI3g binary data
 #' will be used.
-#' @param water2na Logical. If \code{TRUE} (default), pixels with 'mask-water'
-#' value (-10000) will be discarded. See also
-#' \url{http://ecocast.arc.nasa.gov/data/pub/gimms/3g.v0/00READMEgeo.txt}.
-#' @param nodata2na Logical. If \code{TRUE} (default), pixels with 'mask-nodata'
-#' value (-5000) will be discarded.
-#' @param scaling Logical. If \code{TRUE} (default), initial values will be
-#' scaled by a factor of 1/10000.
-#' @param remove_header Logical. If \code{FALSE} (default), the header file
-#' specified in 'header' or, if not specified, created internally via
-#' \code{gimms:::createHeader} will be removed after all operations have finished.
+#' @param water2na Logical. Determines whether or not to discard pixels with
+#' 'mask-water' value (-10000; see 'References').
+#' @param nodata2na Logical. Determines whether or not to discard pixels with
+#' 'mask-nodata' value (-5000; see 'References').
+#' @param scaling Logical. If \code{TRUE} (default), scaling is enabled which
+#' allows to retrieve NDVI or flag values (depending on 'flag').
+#' @param remove_header Logical. If \code{TRUE}, the header file specified in
+#' 'header' or, if not specified, created internally via
+#' \code{gimms:::createHeader} is removed after all operations have finished.
 #' @param cores Integer. Number of cores for parallel computing. If 'filename'
 #' is not specified, the parallel option is automatically disabled.
 #' @param filename Character. Optional vector of output filenames with the same
@@ -35,6 +37,12 @@
 #' @seealso
 #' \code{gimms:::createHeader}, \code{\link{raster}}, \code{\link{writeRaster}}.
 #'
+#' @references
+#' \url{https://nex.nasa.gov/nex/projects/1349/wiki/general_data_description_and_access/}
+#' (accessed on January 15, 2016).
+#' \url{http://ecocast.arc.nasa.gov/data/pub/gimms/3g.v0/00READMEgeo.txt}
+#' (accessed on January 15, 2016).
+#'
 #' @examples
 #' \dontrun{
 #' ## Download sample data
@@ -52,6 +60,7 @@
 #' @export rasterizeGimms
 #' @name rasterizeGimms
 rasterizeGimms <-   function(x,
+                             flag = FALSE,
                              header = NULL,
                              water2na = TRUE,
                              nodata2na = TRUE,
@@ -65,6 +74,10 @@ rasterizeGimms <-   function(x,
   if (length(x) != length(filename) & all(nchar(filename)) > 0)
     stop("Parameters 'x' and 'filename' are of unequal length.")
 
+  ## check 'cores'
+  cores <- checkCores(cores)
+
+
   ### single core --------------------------------------------------------------
 
   if (cores == 1L | nchar(filename[1]) == 0) {
@@ -93,8 +106,14 @@ rasterizeGimms <-   function(x,
         rst[rst[] == -5000] <- NA
 
       # scale values (optional)
-      if (scaling)
-        rst <- rst / 10000
+      if (scaling) {
+        # create flags
+        if (flag)
+          rst <- rst - floor(rst/10) * 10 + 1
+        # create ndvi
+        else
+          rst <- floor(rst/10) / 1000
+      }
 
       # store output (optional)
       if (length(filename) >= i & nchar(filename[i]) > 0)
@@ -145,8 +164,14 @@ rasterizeGimms <-   function(x,
         rst[rst[] == -5000] <- NA
 
       # scale values (optional)
-      if (scaling)
-        rst <- rst / 10000
+      if (scaling) {
+        # create flags
+        if (flag)
+          rst <- rst - floor(rst/10) * 10 + 1
+        # create ndvi
+        else
+          rst <- floor(rst/10) / 1000
+      }
 
       # store output (optional)
       if (length(filename) >= i & nchar(filename[i]) > 0)
